@@ -160,20 +160,20 @@ test_that("maths", {
 })
 
 
-test_that("select variables", {
-  expect_equal(ac('{"foo": 5, "bar": 7}' %>% select(a = .foo) %>% jq), '{"a":5}')
+test_that("construct objects", {
+  expect_equal(ac('{"foo": 5, "bar": 7}' %>% build_object(a = .foo) %>% jq), '{"a":5}')
 
   # using json dataset, just first element
   x <- commits %>% index(0)
-  expect_equal(ac(x %>% select(message = .commit.message, name = .commit.committer.name) %>% jq),
+  expect_equal(ac(x %>% build_object(message = .commit.message, name = .commit.committer.name) %>% jq),
                '{\"message\":[\"Add wrapping and clamping to jv_array_slice\\n\\nFix #716.  Fix #717.\"],\"name\":[\"Nicolas Williams\"]}')
-  expect_equal(ac(x %>% select(sha = .commit.tree.sha, author = .author.login) %>% jq),
+  expect_equal(ac(x %>% build_object(sha = .commit.tree.sha, author = .author.login) %>% jq),
                '{\"sha\":[\"a52a4b412c3ba4bd2e237f37a5f11fd565e74bae\"],\"author\":[\"tgockel\"]}')
 
   # using json dataset, all elements
   x <- index(commits)
   zz <- x %>%
-     select(message = .commit.message, name = .commit.committer.name)
+     build_object(message = .commit.message, name = .commit.committer.name)
   expect_is(zz, "jqson")
   expect_equal(base::length(zz), 5)
 })
